@@ -19,8 +19,6 @@ def Demo(mainUrl, functionString, numberOfVariables, variables, values, interval
 
     response = requests.request("POST", url, data=payload)
 
-    print(response.text)
-
     return response
 
 def CreateComputation(mainUrl, functionString, numberOfVariables, variables, values, interval):
@@ -32,8 +30,6 @@ def CreateComputation(mainUrl, functionString, numberOfVariables, variables, val
 
     response = requests.request("POST", url, data=payload)
 
-    print(response.text)
-
     return response
 
 def GetComputationResult(mainUrl, handle_pacevalComputation, values,):
@@ -45,8 +41,6 @@ def GetComputationResult(mainUrl, handle_pacevalComputation, values,):
 
     response = requests.request("POST", url, data=payload)
 
-    print(response.text)
-
     return response
 
 def GetErrorInformation(mainUrl, handle_pacevalComputation):
@@ -58,8 +52,6 @@ def GetErrorInformation(mainUrl, handle_pacevalComputation):
 
     response = requests.request("POST", url, data=payload)
 
-    print(response.text)
-
     return response
 
 def GetComputationResultExt(mainUrl, handle_pacevalComputation, numberOfCalculations, values,):
@@ -71,8 +63,6 @@ def GetComputationResultExt(mainUrl, handle_pacevalComputation, numberOfCalculat
 
     response = requests.request("POST", url, data=payload)
 
-    print(response.text)
-
     return response
 
 def GetComputationInformationXML(mainUrl, handle_pacevalComputation):
@@ -84,7 +74,16 @@ def GetComputationInformationXML(mainUrl, handle_pacevalComputation):
 
     response = requests.request("POST", url, data=payload)
 
-    print(response.text)
+    return response
+
+def GetMultipleComputationsResult(mainUrl, handle_pacevalComputations, values):
+
+    urlSchema = mainUrl + "/GetComputationInformationXML/?handle_pacevalComputations={}&numberOfpacevalComputations={}&values={}"
+    url = urlSchema.format(handle_pacevalComputations, values)
+
+    payload={}
+
+    response = requests.request("POST", url, data=payload)
 
     return response
 
